#!/bin/sh

#echo "---------- EMS Transcoder Script ----------"
# This is a transcoder script example used by transcode API of EMS

# Transcoder binary, change as needed
TRANSCODER_BIN=./evo-avconv
if [ ! -x $TRANSCODER_BIN ]
then
	echo "$TRANSCODER_BIN not found or wrong permissions"
	exit 1
fi

# We're using AVCONV for now, add the preset files path as well
export AVCONV_DATADIR=../evo-avconv-presets

# Encoders being used
ENC_VIDEO="libx264"
ENC_AUDIO="libfaac"

########## MAKE ONLY NECESSARY CHANGES BEYOND THIS POINT ##########

# Function to form the needed parameter
# $1 - value to be evaluated
# $2 - prepended to $1 if it is not '0'
# $3 - value to replace $1 if IT IS '0'
# $4 - trigger flag
formParams() {
  # Check for triggers first
  if [ -n "$4" ] && [ "$4" = "0" ]; then
    # Do nothing and just return since trigger is 0 (disabled)
    echo ""
  else
    # Trigger is passed and not "0"
    case "$1" in
      "na")
        # Do nothing
        echo ""
        ;;

      "copy")
        # Do nothing
        echo ""
        ;;

      "0")
        # Check if this $3 is not also '0'
        if [ "$3" = "0" ]; then
          # Do nothing
          echo ""
        else
          # Disable the track
          echo " -$3"
        fi
        ;;

      *)
        # Default option
        echo " -$2 $1"
        ;;
    esac
  fi
}

# -- parameters passed to this script --
EMS_SRC_URI=$1
EMS_VIDEO_BITRATE=$2
EMS_VIDEO_SIZE=$3
EMS_VIDEO_APP=$4
EMS_AUDIO_BITRATE=$5
EMS_AUDIO_CHANNELS=$6
EMS_AUDIO_FREQ=$7
EMS_AUDIO_APP=$8
EMS_OVERLAY=$9
EMS_CROP_X_POS=${10}
EMS_CROP_Y_POS=${11}
EMS_CROP_WIDTH=${12}
EMS_CROP_HEIGHT=${13}
EMS_DST_URI=${14}
EMS_DST_STREAM_NAME=${15}
EMS_CMD_FLAGS=${16}

# Enable file overwrite by default
TRANSCODE="-y"

# Add the extra param
if [ -n "$EMS_RTSP_TRANSPORT" ]; then
  TRANSCODE="$TRANSCODE -rtsp_transport tcp"
fi

# Add -re param as needed
if [ -n "$EMS_FORCE_RE" ]; then
  TRANSCODE="$TRANSCODE -re"
fi

# Add the source
TRANSCODE="$TRANSCODE -i $EMS_SRC_URI"

# Add the overlay and cropping as a single video filter
HAS_OVERLAY=$(formParams $EMS_OVERLAY 0 0)
HAS_CROPPING=$(formParams $EMS_CROP_WIDTH 0 0)

# If we have an overlay, setup the parameter
if [ -n "$HAS_OVERLAY" ]; then
  OVERLAY_CROPPING=" -i $EMS_OVERLAY -filter_complex overlay"
fi

# If we have cropping, setup the parameter
if [ -n "$HAS_CROPPING" ]; then
  CROPPING_PARAM="$EMS_CROP_WIDTH:$EMS_CROP_HEIGHT"

  # Check if we also have x and y positions
  if [ "$EMS_CROP_X_POS" != "na" ]; then
    CROPPING_PARAM="$CROPPING_PARAM:$EMS_CROP_X_POS:$EMS_CROP_Y_POS"
  fi

  OVERLAY_CROPPING=" -filter_complex crop=$CROPPING_PARAM"
fi

# If we have both, use a single filter_complex param
if [ -n "$HAS_OVERLAY" ] && [ -n "$HAS_CROPPING" ]; then
  OVERLAY_CROPPING=" -i $EMS_OVERLAY -filter_complex overlay,crop=$CROPPING_PARAM"
fi

# Add the overlay/cropping
TRANSCODE="$TRANSCODE$OVERLAY_CROPPING"

# Flag to indicate if we need to reencode video or not
REENCODE=0

# Check if we need reencoding
if [ -n "$OVERLAY_CROPPING" ]; then
  REENCODE=1
fi

# Add the video bitrate
TMP_VALUE=$(formParams $EMS_VIDEO_BITRATE b:v vn)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ] && [ "$TMP_VALUE" != " -vn" ]; then
  REENCODE=1
fi

# Add the video size
TMP_VALUE=$(formParams $EMS_VIDEO_SIZE s vn $EMS_VIDEO_BITRATE)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ]; then
  REENCODE=1
fi

# Add the video preset profile
TMP_VALUE=$(formParams $EMS_VIDEO_APP pre:v vn $EMS_VIDEO_BITRATE)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ]; then
  REENCODE=1
fi

# Add the output video codec
if [ $REENCODE = 1 ]; then
  TRANSCODE="$TRANSCODE -c:v $ENC_VIDEO"
else
  TRANSCODE="$TRANSCODE -c:v copy"
fi

# Flag to indicate if we need to reencode audio or not
REENCODE=0

# Add the audio bitrate
TMP_VALUE=$(formParams $EMS_AUDIO_BITRATE b:a an)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ] && [ "$TMP_VALUE" != " -an" ]; then
  REENCODE=1
fi

# Add the audio channel count
TMP_VALUE=$(formParams $EMS_AUDIO_CHANNELS ac an $EMS_AUDIO_BITRATE)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ]; then
  REENCODE=1
fi

# Add the audio frequency
TMP_VALUE=$(formParams $EMS_AUDIO_FREQ ar an $EMS_AUDIO_BITRATE)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ]; then
  REENCODE=1
fi

# Add the audio preset profile
TMP_VALUE=$(formParams $EMS_AUDIO_APP pre:a an $EMS_AUDIO_BITRATE)
TRANSCODE="$TRANSCODE$TMP_VALUE"

# Check if we need reencoding
if [ -n "$TMP_VALUE" ]; then
  REENCODE=1
fi

# Add the output audio codec
if [ $REENCODE = 1 ]; then
  TRANSCODE="$TRANSCODE -c:a $ENC_AUDIO"
else
  TRANSCODE="$TRANSCODE -c:a copy"
fi

# Add the target streamName
TRANSCODE="$TRANSCODE $EMS_CMD_FLAGS -metadata streamName=$EMS_DST_STREAM_NAME"

# Add the destination
TRANSCODE="$TRANSCODE $EMS_DST_URI"

# Run the binary
#echo "$TRANSCODER_BIN $TRANSCODE"
exec $TRANSCODER_BIN -loglevel error $TRANSCODE

