<?php

/**
 *
 * Copyright (c) 2013, EvoStream Inc.  All rights reserved.
 *
 * This software is provided free of charge to be used solely in conjunction
 * with the EvoStream Media Server.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the source code retain the above 
 * copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
 **/

//1. Load the configuration
require_once 'config/config.php';

//	1.a Validate that php curl is enabled before going to next process
validateCurl();

//2. get the event from the pipe
$event = getEvent();

//3. Get the stack of plugins
$plugins = getPluginsStack();

//4. Call each plugin
foreach ($plugins as $plugin) {
	
	//Is this plugin supporting this event type?
	if ($plugin->supportsEvent($event->type) !== true)
		continue;

	//execute the plugin
	$continue = $plugin->processEvent($event);
	
	//should we continue?
	if ($continue !== true)
		break;
}


// ------------------------------------------------------------------------

/**
 * Get Event from the $_POST input
 * @return array
 */	
function getEvent() {	

	//Get the event from pipe and json_decode it
	return json_decode(file_get_contents('php://input'));
}

/**
 * Validate that php curl is enabled
 */	
function validateCurl(){
	// Before anything else, check if we have php-curl is installed
	if (!function_exists('curl_init')) {
		error_log("Kindly install/enable php-curl module and try again. This standard module allows the webserver to communicate with the EMS.");
		exit();
	}
}

?>
